<?php

  function affyb_setup() {

    load_theme_textdomain( 'affyb', get_template_directory() . '/languages' );

    require_once(get_template_directory()  . '/inc/affyb-options.php'); // Load options for haiku theme

    register_nav_menus(
      array(
        'primary-nav'   => __( 'Primary navigation menu', 'affyb' ),
        'footer-nav' => __( 'Footer navigation menu', 'affyb' ), // This menu appears in the footer
      )
    );

    function affyb_widgets_init() {
      
      register_sidebar( array(  // Register Main Sidebar and add class "widget" to the widget
        'name' => __( 'Main Sidebar', 'affyb' ),
        'id' => 'sidebar',
        'description' => __( 'Add widgets here to view them in the Main Sidebar.', 'affyb' ),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title">',
        'after_title' => '</h5>',
      ) );

      register_sidebar( array(  // Register Footer Sidebar and add class "widget-footer" to the widget
        'name' => __( 'Footer Sidebar', 'affyb' ),
        'id' => 'sidebar-footer',
        'description' => __( 'Add widgets here to view them in the Footer Sidebar.', 'affyb' ),
        'before_widget' => '<div id="%1$s" class="widget-footer %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-footer-title">',
        'after_title' => '</h5>',
      ) );

    }
    add_action( 'widgets_init', 'affyb_widgets_init' );

    add_theme_support( 'automatic-feed-links' );

    add_theme_support( 'post-thumbnails' );

    add_theme_support( 'title-tag' );

    add_theme_support( 'html5', array(
      'comment-list',
      'search-form',
      'comment-form',
      'gallery',
      'caption',
    ) );

    add_theme_support( 'custom-logo', array( // Add theme support for Custom Logo.
      'height'      => 80,
      'width'       => 80,
      'flex-height' => true,
      'flex-width'  => true,
      'header-text' => array( 'site-title', 'site-description' ),
    ) );

    add_theme_support( 'custom-header', array ( // Add theme support for Custom Header image.
      'height'              => 250,
      'width'               => 1200,
      'flex-height'         => true,
      'flex-width'          => true,
      'default-text-color'  => '#23282d',
      'uploads'             => true
    ) );

    add_theme_support( 'custom-background', array ( // Add theme support for background image.
      'default-color'       => '#002530',
      'default-repeat'      => 'repeat',
      'default-position-x'  => 'center',
      'default-position-y'  => 'center',
      'default-size'        => 'auto',
      'default-attachment'  => 'fixed',
    ) );

    add_editor_style( get_template_directory_uri() . '/assets/css/other/editor-style.css' ); // Add custom editor style to wordpress editor

    if ( ! isset( $content_width ) ) {
      $content_width = 600;
    }

  }
  add_action('after_setup_theme', 'affyb_setup');

  function affyb_add_styles() {
    wp_enqueue_style( 'affyb', get_stylesheet_uri() );
  }
  add_action( 'wp_enqueue_scripts', 'affyb_add_styles' );
  
	function affyb_adding_scripts() {

    wp_register_script('affyb_js_translate', get_template_directory_uri()  . '/assets/js/scripts.js', array('jquery'),null, true);
    
    wp_register_script('affyb_js_validate', get_template_directory_uri()  . '/assets/js/vendor/jquery.validate.js', array('jquery'),null, true);
    
    wp_enqueue_script('affyb_js_translate');

		$translation_array = array(
			'placeholderval1' => __( 'What you are looking for', 'affyb' ),
      'placeholderval2' => __( 'You did not write anything, try again', 'affyb' ),
      'template_directory_uri' => get_template_directory_uri(),
    );
    
    wp_localize_script( 'affyb_js_translate', 'object_name', $translation_array );
    
    if (is_singular()) {
      wp_enqueue_script('affyb_js_validate');
    }
    
	}
  add_action( 'wp_enqueue_scripts', 'affyb_adding_scripts' );

	function affyb_adding_login_scripts_style() {

    wp_enqueue_style( 'custom-login', get_template_directory_uri() . '/assets/css/other/style-login.css' );
    
    wp_register_script('affyb_login_js_translate', get_template_directory_uri()  . '/assets/js/style-login.js', array('jquery'),null, false);
    
    wp_enqueue_script('affyb_login_js_translate');
    
    $translation_array = array(
			'backto' => __( 'Return to', 'affyb' )  . '&nbsp;' . get_bloginfo( 'name' ),
    );
    
    wp_localize_script( 'affyb_login_js_translate', 'object_name', $translation_array );
    
	}
  add_action( 'login_footer', 'affyb_adding_login_scripts_style' );

  function affyb_custom_excerpt_length($length) { // custom excerpt length
    global $excerpt_lenght;
    if ( get_option( 'excerpt_lenght' ) ) {
      $excerpt_lenght = get_option('excerpt_lenght');
    }
    else {
      $excerpt_lenght = 80;
    }
    return $excerpt_lenght;
  }
  add_filter('excerpt_length', 'affyb_custom_excerpt_length', 999);

	function affyb_excerpt_more($more) {
		global $post;
		return '<div class="read-more"><a href="' . get_permalink($post->ID) . '">' . __( 'Read more', 'affyb' ) . '</a></div>';
	}
  add_filter('excerpt_more', 'affyb_excerpt_more');
  
  function affyb_add_comment_author_to_reply_link($link, $args, $comment) {
    $comment = get_comment( $comment );
    if ( empty($comment->comment_author) ) {
      if (!empty($comment->user_id)){
        $user=get_userdata($comment->user_id);
        $author=$user->user_login;
      } else {
        $author = __('Anonymous', 'affyb');
      }
    } else {
      $author = $comment->comment_author;
    }
    if(strpos($author, ' ')) {
      $author = substr($author, 0, strpos($author, ' '));
    }
    $reply_link_text = $args['reply_text'];
    $link = str_replace($reply_link_text, '<span class="respond-to">' . __('Respond to', 'affyb') . ' ' . '</span>' . $author . '', $link);
    return $link;
  }
  add_filter('comment_reply_link', 'affyb_add_comment_author_to_reply_link', 10, 3);

  function affyb_comment_placeholders($fields) {
    $fields['author'] = str_replace(
      '<input',
      '<input placeholder="' . __('Name', 'affyb') . '"',
      $fields['author']
      );
    $fields['email'] = str_replace(
      '<input',
      '<input placeholder="' . __('your@email.com...', 'affyb') . '"',
      $fields['email']
      );
    $fields['url'] = str_replace(
      '<input',
      '<input placeholder="' . __('your website...', 'affyb') . '"',
      $fields['url']
      );
    return $fields;
  }
  add_filter('comment_form_default_fields', 'affyb_comment_placeholders');

  function affyb_modify_comment_form_text_area($arg) {
    $arg['comment_field'] = '<p class="comment-form-comment"><label for="comment">' . __('your comment', 'affyb') . '<span class="required"> *</span></label><textarea id="comment" name="comment" cols="45" rows="1" aria-required="true"></textarea></p>';
    return $arg;
  }
  add_filter('comment_form_defaults', 'affyb_modify_comment_form_text_area');

  function affyb_textarea_placeholder( $fields ) {
    $fields['comment_field'] = str_replace(
      '<textarea',
      '<textarea placeholder="' . __('Write your comment...', 'affyb') . '"',
      $fields['comment_field']
      );
    return $fields;
  }
  add_filter('comment_form_defaults', 'affyb_textarea_placeholder');

  function affyb_comment_validation_init() {
    if(is_singular() && comments_open() ) { ?>
      <script type="text/javascript">
        jQuery(document).ready(function($) {
          $('#commentform').validate({
            rules: {
              author: {
                required: true,
                minlength: 2
              },
              email: {
                required: true,
                email: true
              },
              comment: {
                required: true,
                minlength: 20
              }
            },
            messages: {
              author: "<?php echo __( 'write your name', 'affyb' ); ?>",
              email: "<?php echo __( 'enter a valid emal', 'affyb' ); ?>",
              comment: "<?php echo __( 'write your comment (20 chars minimum)', 'affyb' ); ?>"
            },
            errorElement: "div",
            errorPlacement: function(error, element) {
              element.before(error);
            }
          });
        });
      </script>
      <?php
    }
  }
  add_action('wp_footer', 'affyb_comment_validation_init');

  function affyb_login_logo_default() { 
    $custom_logo_id = get_theme_mod( 'custom_logo' );
    $image = wp_get_attachment_image_src( $custom_logo_id , 'full' );
  ?> 
    <style type="text/css"> 
      #login h1 a {
        background-image: url(' <?php echo $image[0]; ?>');
      } 
    </style>
  <?php }
  add_action( 'login_enqueue_scripts', 'affyb_login_logo_default' );

  function affyb_loginpage_custom_link() {
    return home_url();
  }
  add_filter('login_headerurl','affyb_loginpage_custom_link');

  function affyb_change_title_on_logo() {
    return get_bloginfo('title');
  }
  add_filter('login_headertitle', 'affyb_change_title_on_logo');

  function affyb_login_head() {
    remove_action('login_head', 'wp_shake_js', 12);
  }
  add_action('login_head', 'affyb_login_head');

  function affyb_custom_login_message() {
    $message = '<div class="login-message">' . __('You can reach the source, but to do this you need the key manufacturer...', 'affyb') . '</div>';
    return $message;
  }
  add_filter('login_message', 'affyb_custom_login_message');

  function affyb_login_error_override()	{
    return __('Login error', 'affyb');
  }
  add_filter('login_errors', 'affyb_login_error_override');
  
?>